Posts — Stisla

# Posts

Add New

## Posts

You can manage all posts, such as editing, deleting and more.

#### All Posts

| Title | Category | Author | Created At | Status
--- | --- | --- | --- | --- | ---
| Laravel 5 Tutorial: Introduction View Edit Trash | Web Developer, Tutorial | Rizal Fakhri | 2018-01-20 | Published
| Laravel 5 Tutorial: Installing View Edit Trash | Web Developer, Tutorial | Rizal Fakhri | 2018-01-20 | Published
| Laravel 5 Tutorial: MVC View Edit Trash | Web Developer, Tutorial | Rizal Fakhri | 2018-01-20 | Published
| Laravel 5 Tutorial: CRUD View Edit Trash | Web Developer, Tutorial | Rizal Fakhri | 2018-01-20 | Draft
| Laravel 5 Tutorial: Deployment View Edit Trash | Web Developer, Tutorial | Rizal Fakhri | 2018-01-20 | Pending